@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@ import hashlib
 import filecmp
 import logging
 import os
-import six
 import sys
 import textwrap
 import yaml
@@ -60,6 +59,7 @@ class ConfigParserProgram(object):
         "bgpq3_path": "bgpq4",
         "bgpq3_host": IRRDBInfo.BGPQ3_DEFAULT_HOST,
         "bgpq3_sources": IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
+        "bgpq3_timeout": IRRDBInfo.BGPQ3_DEFAULT_TIMEOUT,
 
         "rtt_getter_path": "",
 
@@ -90,7 +90,7 @@ class ConfigParserProgram(object):
     def load(self, path_or_file):
         self._reset_to_default()
 
-        if isinstance(path_or_file, six.string_types):
+        if isinstance(path_or_file, str):
             path = path_or_file
 
             if path and not os.path.exists(os.path.expanduser(path)):
@@ -127,6 +127,10 @@ class ConfigParserProgram(object):
         else:
             self.cfg["cfg_dir"] = os.path.dirname(os.path.expanduser(path))
 
+        if isinstance(self.cfg["bgpq3_host"], str):
+            list_as_str = self.cfg["bgpq3_host"]
+            self.cfg["bgpq3_host"] = list(map(str.strip, list_as_str.split(",")))
+
         # relative path -> absolute path
         for cfg_key in self.PATH_KEYS:
             if not self.cfg[cfg_key]:
