@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -145,6 +145,9 @@ class RPKIROAsEnricher(BaseConfigEnricher):
             roa_payload = {"prefix": prefix, "length": prefix_obj.prefixlen,
                            "max_len": max_len, "asn": asn}
 
+            if "expires" in roa:
+                roa_payload["expires"] = int(roa["expires"])
+
             prefix_len = str(prefix_obj.prefixlen)
             if prefix_len not in self.builder.rpki_roas:
                 self.builder.rpki_roas[prefix_len] = [roa_payload]
